@@ -18,4 +18,4 @@ import jpype
 import os.path
 
 jvmlib = jpype.getDefaultJVMPath()
-print os.path.dirname(os.path.dirname(jvmlib))
+print(os.path.dirname(os.path.dirname(jvmlib)))
