@@ -69,7 +69,8 @@ class JDBCType(object):
         _types.append(self)
         if _jpype.isStarted():
             java = _jpype._JPackage("java")
-            self._initialize(java.sql.CallableStatement, java.sql.PreparedStatement, java.sql.ResultSet)
+            self._initialize(java.sql.CallableStatement,
+                             java.sql.PreparedStatement, java.sql.ResultSet)
 
     def _initialize(self, cs, ps, rs):
         """ Called after the JVM starts initialize Java resources """
@@ -96,7 +97,8 @@ class JDBCType(object):
                 return self._csget(rs, column)
             return self._rsget(rs, column)
         except _SQLException as ex:
-            raise InterfaceError("Unable to get '%s' using '%s'" % (self._name, self._getter)) from ex
+            raise InterfaceError("Unable to get '%s' using '%s'" %
+                                 (self._name, self._getter)) from ex
 
     def set(self, ps, column, value):
         """ A method used to set a parameter to a query.
@@ -116,9 +118,11 @@ class JDBCType(object):
             # Otherwise, try to set with the generic method
             return ps.setObject(column, value)
         except TypeError as ex:
-            raise InterfaceError("Unable to convert '%s' into '%s'" % (type(value).__name__, self._name)) from ex
+            raise InterfaceError("Unable to convert '%s' into '%s'" % (
+                type(value).__name__, self._name)) from ex
         except OverflowError as ex:
-            raise InterfaceError("Unable to convert '%s' into '%s' calling '%s'" % (type(value).__name__, self._name, self._setter)) from ex
+            raise InterfaceError("Unable to convert '%s' into '%s' calling '%s'" % (
+                type(value).__name__, self._name, self._setter)) from ex
 
     def __repr__(self):
         if self._name is None:
@@ -143,7 +147,8 @@ class _JDBCTypePrimitive(JDBCType):
                 return None
             return rc
         except _SQLException as ex:
-            raise InterfaceError("Unable to get '%s' using '%s'" % (self._name, self._getter)) from ex
+            raise InterfaceError("Unable to get '%s' using '%s'" %
+                                 (self._name, self._getter)) from ex
 
 
 # From https://www.cis.upenn.edu/~bcpierce/courses/629/jdkdocs/guide/jdbc/getstart/mapping.doc.html
@@ -180,7 +185,8 @@ SQLXML = JDBCType('SQLXML', 2009, 'getSQLXML', 'setSQLXML')
 TIME = JDBCType('TIME', 92, 'getTime', 'setTime')
 TIME_WITH_TIMEZONE = JDBCType('TIME_WITH_TIMEZONE', 2013, 'getTime', 'setTime')
 TIMESTAMP = JDBCType('TIMESTAMP', 93, 'getTimestamp', 'setTimestamp')
-TIMESTAMP_WITH_TIMEZONE = JDBCType('TIMESTAMP_WITH_TIMEZONE', 2014, 'getTimestamp', 'setTimestamp')
+TIMESTAMP_WITH_TIMEZONE = JDBCType(
+    'TIMESTAMP_WITH_TIMEZONE', 2014, 'getTimestamp', 'setTimestamp')
 TINYINT = _JDBCTypePrimitive('TINYINT', -6, 'getShort', 'setShort')
 VARBINARY = JDBCType('VARBINARY', -3, 'getBytes', 'setBytes')
 VARCHAR = JDBCType('VARCHAR', 12, 'getString', 'setString')
@@ -203,8 +209,10 @@ DATETIME = TIMESTAMP
 # Special types
 ASCII_STREAM = JDBCType(None, None, 'getAsciiStream', 'setAsciiStream')
 BINARY_STREAM = JDBCType(None, None, 'getBinaryStream', 'setBinaryStream')
-CHARACTER_STREAM = JDBCType(None, None, 'getCharacterStream', 'setCharacterStream')
-NCHARACTER_STREAM = JDBCType(None, None, 'getNCharacterStream', 'setNCharacterStream')
+CHARACTER_STREAM = JDBCType(
+    None, None, 'getCharacterStream', 'setCharacterStream')
+NCHARACTER_STREAM = JDBCType(
+    None, None, 'getNCharacterStream', 'setNCharacterStream')
 URL = JDBCType(None, None, 'getURL', 'setURL')
 
 # The converters are defined in a customizer
@@ -244,8 +252,8 @@ def SETTERS_BY_META(cx, meta, col, ptype):
     """ Option for setters to use the metadata of the parameters.
 
     On some databases this option is useless as they do not track parameter
-    types.  This method can be cached for faster performance when lots of
-    parameters.  Usually types can only be determined accurately on inserts
+    types.  This method can be cached for faster performance when the are lots
+    of parameters.  Usually types can only be determined accurately on inserts
     into defined columns.
     """
     return _default_map[_registry[meta.getParameterType(col + 1)]]
@@ -282,12 +290,12 @@ def GETTERS_BY_TYPE(cx, meta, idx):
 
 
 def GETTERS_BY_NAME(cx, meta, idx):
-    """ Option to getters to determine column type by the column name.
+    """ Option for getters to determine column type by the column name.
 
     This option uses the column name to select the type.  It looks up
     the column type name, converts it to uppercase, and then searches
-    for a matchine type.  It falls back to the type code meta information if
-    the typename can not be found in the registery.  New types can be created
+    for a matching type.  It falls back to the type code meta information if
+    the type name cannot be found in the registry.  New types can be created
     using JDBCType for database specific types such as ``JSON``.
     """
     name = str(meta.getColumnTypeName(idx + 1)).upper()
@@ -388,7 +396,7 @@ def connect(dsn, *, driver=None, driver_args=None,
        dsn (str): The database connection string for JDBC.
        driver (str, optional): A JDBC driver to load.
        driver_args: Arguments to the driver.  This may either be a dict,
-          java.util.Properties.  If not supplied, kwargs are used as as the
+          java.util.Properties.  If not supplied, kwargs are used as the
           parameters for the JDBC connection.
        *kwargs: Arguments to the driver if not supplied as
           driver_args.
@@ -401,8 +409,10 @@ def connect(dsn, *, driver=None, driver_args=None,
     """
     Properties = _jpype.JClass("java.util.Properties")
     if driver:
-        _jpype.JClass('java.lang.Class').forName(driver).newInstance()
+        _jpype.JClass('java.lang.Class').forName(
+            driver, True, _jpype.JPypeClassLoader).newInstance()
     DM = _jpype.JClass('java.sql.DriverManager')
+    # DM.setLogStream(_jpype.JClass("java.lang.System").out)
 
     # User is supplying Java properties
     if isinstance(driver_args, Properties):
@@ -432,7 +442,7 @@ def connect(dsn, *, driver=None, driver_args=None,
 class Connection(object):
     """ Connection provides access to a JDBC database.
 
-    Connections are managed and can be as part of a Python with statement.
+    Connections are managed and can be used as part of a Python 'with' statement.
     Connections close automatically when they are garbage collected, at the
     end of a with statement scope, or when manually closed.  Once a connection
     is closed all operations using the database will raise an Error.
@@ -528,7 +538,7 @@ class Connection(object):
 
     @property
     def setters(self):
-        """ Setter are used to set parameters to ``.execute*()`` methods.
+        """ Setters are used to set parameters to ``.execute*()`` methods.
 
         Setters should be a function taking (connection, meta, col, type) -> JDBCTYPE
         """
@@ -578,7 +588,7 @@ class Connection(object):
     def commit(self):
         """Commit any pending transaction to the database.
 
-        Calling commit on a cooonection that does not support the operation
+        Calling commit on a connection that does not support the operation
         will raise NotSupportedError.
         """
         self._validate()
@@ -593,8 +603,8 @@ class Connection(object):
         """Rollback the transaction.
 
         This method is optional since not all databases provide transaction
-        support.  Calling rollback on a cooonection that does not support will
-        raise NotSupportedError.
+        support.  Calling rollback on a connection that does not support it 
+        will raise NotSupportedError.
 
         In case a database does provide transactions this method causes the
         database to roll back to the start of any pending transaction. Closing
@@ -707,7 +717,8 @@ class Cursor(object):
         if types is None:
             types = [None] * count
         if isinstance(params, str):
-            raise _UnsupportedTypeError("parameters must be a sequence of values")
+            raise _UnsupportedTypeError(
+                "parameters must be a sequence of values")
         if isinstance(params, typing.Sequence):
             if count != len(params):
                 raise ProgrammingError("incorrect number of parameters (%d!=%d)"
@@ -725,7 +736,8 @@ class Cursor(object):
                     s = cx._setters(cx, meta, i, type(p))
                     types[i] = s
                 if s is None:
-                    raise _UnsupportedTypeError("no setter found for '%s'" % type(p).__name__)
+                    raise _UnsupportedTypeError(
+                        "no setter found for '%s'" % type(p).__name__)
                 s.set(self._statement, i + 1, p)
             # Cache
             if hasattr(cx._setters, "_cachable"):
@@ -735,7 +747,8 @@ class Cursor(object):
         elif isinstance(params, typing.Iterable):
             for i, p in enumerate(params):
                 if i >= count:
-                    raise ProgrammingError("incorrect number of parameters (%d!=%d)" % (count, i + 1))
+                    raise ProgrammingError(
+                        "incorrect number of parameters (%d!=%d)" % (count, i + 1))
 
                 # Find and apply the adapter
                 a = cx._adapters.get(type(p), None)
@@ -747,15 +760,18 @@ class Cursor(object):
                     s = cx._setters(cx, meta, i, type(p))
                     types[i] = s
                 if s is None:
-                    raise _UnsupportedTypeError("no setter found for '%s'" % type(p).__name__)
+                    raise _UnsupportedTypeError(
+                        "no setter found for '%s'" % type(p).__name__)
                 s.set(self._statement, i + 1, p)
             if count != i + 1:
-                raise ProgrammingError("incorrect number of parameters (%d!=%d)" % (count, i + 1))
+                raise ProgrammingError(
+                    "incorrect number of parameters (%d!=%d)" % (count, i + 1))
             # Cache
             if hasattr(cx._setters, "_cachable"):
                 self._parameterTypes = types
         else:
-            raise _UnsupportedTypeError("'%s' parameters not supported" % (type(params).__name__))  # pragma: no cover
+            raise _UnsupportedTypeError("'%s' parameters not supported" % (
+                type(params).__name__))  # pragma: no cover
 
     def _onResultSet(self, rs):
         meta = rs.getMetaData()
@@ -839,8 +855,8 @@ class Cursor(object):
 
     @property
     def parameters(self):
-        """ (extension) Parameters is read-only attribute is a sequence of
-        6-item sequences.
+        """ (extension) Parameters is a read-only attribute. It is a sequence
+        of 6-item sequences.
 
         Each of these sequences contains information describing one result
         column:
@@ -869,7 +885,7 @@ class Cursor(object):
 
     @property
     def description(self):
-        """ Description is read-only attribute is a sequence of 7-item
+        """ Description is a read-only attribute. It is a sequence of 7-item
         sequences.
 
         Each of these sequences contains information describing one result
@@ -909,7 +925,7 @@ class Cursor(object):
         .execute*() affected (for DML statements like UPDATE or INSERT).
 
         The attribute is -1 in case no .execute*() has been performed on the
-        cursor or the rowcount of the last operation is cannot be determined by
+        cursor or the rowcount of the last operation cannot be determined by
         the interface.  JDBC does not support getting the number of rows
         returned from SELECT, so for most drivers rowcount will be -1 after a
         SELECT statement.
@@ -948,10 +964,13 @@ class Cursor(object):
             self._validate()
             self._finish()
             if not isinstance(procname, str):
-                raise _UnsupportedTypeError("procname must be str, not '%s'" % type(procname).__name__)
+                raise _UnsupportedTypeError(
+                    "procname must be str, not '%s'" % type(procname).__name__)
             if not isinstance(parameters, typing.Sequence):
-                raise _UnsupportedTypeError("parameters must be sequence, not '%s'" % type(procname).__name__)
-            query = "{CALL %s(%s)}" % (procname, ",".join("?" * len(parameters)))
+                raise _UnsupportedTypeError(
+                    "parameters must be sequence, not '%s'" % type(procname).__name__)
+            query = "{CALL %s(%s)}" % (
+                procname, ",".join("?" * len(parameters)))
             try:
                 self._statement = self._jcx.prepareCall(query)
             except _SQLException as ex:
@@ -966,7 +985,8 @@ class Cursor(object):
                 types = [None] * count
             else:
                 if len(types) != count:
-                    raise ProgrammingError("expected '%d' types, got '%d'" % (count, len(types)))
+                    raise ProgrammingError(
+                        "expected '%d' types, got '%d'" % (count, len(types)))
             for i in range(count):
                 # Lookup the JDBC Type
                 p = parameters[i]
@@ -978,7 +998,8 @@ class Cursor(object):
                     types[i] = cx._setters(cx, meta, i, type(p))
                 jdbcType = types[i]
                 if jdbcType is None:
-                    raise _UnsupportedTypeError("no setter found for '%s'" % type(p).__name__)
+                    raise _UnsupportedTypeError(
+                        "no setter found for '%s'" % type(p).__name__)
 
                 mode = meta.getParameterMode(i + 1)
                 if mode == 1:
@@ -1031,7 +1052,7 @@ class Cursor(object):
         Parameters:
            operation (str): A statement to be executed.
            parameters (list, optional): A list of parameters for the statement.
-              The number of parameters much match the number required by the
+              The number of parameters must match the number required by the
               statement or an Error will be raised.
            keys (bool, optional): Specify if the keys should be available to 
               retrieve. (Default False) 
@@ -1046,7 +1067,8 @@ class Cursor(object):
         if parameters is None:
             parameters = ()
         if not isinstance(parameters, (typing.Sequence, typing.Iterable, typing.Iterator)):
-            raise _UnsupportedTypeError("parameters are of unsupported type '%s'" % type(parameters).__name__)
+            raise _UnsupportedTypeError(
+                "parameters are of unsupported type '%s'" % type(parameters).__name__)
         # complete the previous operation
         try:
             if keys:
@@ -1088,11 +1110,11 @@ class Cursor(object):
         Args:
            operation (str): A statement to be executed.
            seq_of_parameters (list, optional): A list of lists of parameters
-               for the statement.  The number of parameters much match the number
+               for the statement.  The number of parameters must match the number
                required by the statement or an Error will be raised.
            keys (bool, optional): Specify if the keys should be available to 
               retrieve. (Default False) For drivers that do not support
-              batch updates only that last key will be returned.
+              batch updates only the last key will be returned.
 
         Returns:
            This cursor.
@@ -1112,7 +1134,8 @@ class Cursor(object):
         except TypeError as ex:
             raise _UnsupportedTypeError(str(ex))
         except _SQLException as ex:
-            raise ProgrammingError("Failed to prepare '%s'" % operation) from ex
+            raise ProgrammingError(
+                "Failed to prepare '%s'" % operation) from ex
         if self._connection._batch:
             return self._executeBatch(seq_of_parameters)
         else:  # pragma: no cover
@@ -1124,7 +1147,8 @@ class Cursor(object):
                 self._setParams(params)
                 self._statement.addBatch()
         else:
-            raise _UnsupportedTypeError("'%s' is not supported" % type(seq_of_parameters).__name__)
+            raise _UnsupportedTypeError(
+                "'%s' is not supported" % type(seq_of_parameters).__name__)
         try:
             counts = self._statement.executeBatch()
         except _SQLException as ex:  # pragma: no cover
@@ -1147,7 +1171,8 @@ class Cursor(object):
                 except StopIteration:
                     break
         else:
-            raise _UnsupportedTypeError("'%s' is not supported" % str(type(seq_of_parameters)))
+            raise _UnsupportedTypeError(
+                "'%s' is not supported" % str(type(seq_of_parameters)))
         self._rowcount = sum(counts)
         if self._rowcount < 0:
             self._rowcount = -1
@@ -1353,7 +1378,7 @@ def Time(hour, minute, second):
 
 
 def Timestamp(year, month, day, hour, minute, second, nano=0):
-    """ This function constructs an object holding a time stamp value. """
+    """ This function constructs an object holding a timestamp value. """
     return _jpype.JClass('java.sql.Timestamp')(year - 1900, month - 1, day, hour, minute, second, nano)
 
 
@@ -1378,7 +1403,7 @@ def TimeFromTicks(ticks):
 
 def TimestampFromTicks(ticks):
     """
-    This function constructs an object holding a time stamp value from the
+    This function constructs an object holding a timestamp value from the
     given ticks value (number of seconds since the epoch; see the documentation
     of the standard Python time module for details).
     """
