@@ -29,7 +29,7 @@ public:
 			JPClass* super,
 			const JPClassList& interfaces,
 			jint modifiers);
-	virtual ~JPClass();
+	~JPClass() override;
 
 	void setHost(PyObject* host);
 
@@ -40,10 +40,7 @@ public:
 
 	void setHints(PyObject* host);
 
-	PyObject* getHints()
-	{
-		return m_Hints.get();
-	}
+	PyObject* getHints();
 
 public:
 	void ensureMembers(JPJavaFrame& frame);
@@ -149,7 +146,7 @@ public:
 	 *
 	 * @return a java value with class.
 	 */
-	virtual JPValue getValueFromObject(const JPValue& obj);
+	virtual JPValue getValueFromObject(JPJavaFrame& frame, const JPValue& obj);
 
 	/**
 	 * Call a static method that returns this type of object.
@@ -201,10 +198,7 @@ public:
 		return m_Interfaces;
 	}
 
-	JPContext* getContext() const;
-
 protected:
-	JPContext*           m_Context;
 	JPClassRef           m_Class;
 	JPClass*             m_SuperClass;
 	JPClassList          m_Interfaces;
@@ -217,4 +211,4 @@ protected:
 	JPPyObject           m_Hints;
 } ;
 
-#endif // _JPPOBJECTTYPE_H_
\ No newline at end of file
+#endif // _JPPOBJECTTYPE_H_
