@@ -47,11 +47,6 @@ public:
 		return this->m_Field.get();
 	}
 
-	JPContext* getContext()
-	{
-		return m_Class->getContext();
-	}
-
 	const string& getName() const
 	{
 		return m_Name;
@@ -87,4 +82,4 @@ private:
 	jint             m_Modifiers;
 } ;
 
-#endif // _JPFIELD_H_
\ No newline at end of file
+#endif // _JPFIELD_H_
