@@ -30,7 +30,7 @@ class JPGarbageCollection
 {
 public:
 
-	explicit JPGarbageCollection(JPContext *context);
+	explicit JPGarbageCollection();
 
 	void init(JPJavaFrame& frame);
 
@@ -50,14 +50,20 @@ public:
 	void getStats(JPGCStats& stats);
 
 private:
-	JPContext *m_Context;
 	bool running;
 	bool in_python_gc;
 	bool java_triggered;
 	PyObject *python_gc;
 	jclass _SystemClass;
+	jclass _ContextClass;
 	jmethodID _gcMethodID;
 
+	jmethodID _totalMemoryID;
+	jmethodID _freeMemoryID;
+	jmethodID _maxMemoryID;
+	jmethodID _usedMemoryID;
+	jmethodID _heapMemoryID;
+
 	size_t last_python;
 	size_t last_java;
 	size_t low_water;
@@ -69,4 +75,4 @@ private:
 	int python_triggered;
 } ;
 
-#endif /* JP_GC_H */
\ No newline at end of file
+#endif /* JP_GC_H */
