@@ -24,7 +24,7 @@ class JPProxy
 {
 public:
 	friend class JPProxyType;
-	JPProxy(JPContext* context, PyJPProxy* inst, JPClassList& intf);
+	JPProxy(PyJPProxy* inst, JPClassList& intf);
 	virtual ~JPProxy();
 
 	const JPClassList& getInterfaces() const
@@ -34,16 +34,14 @@ public:
 
 	jvalue getProxy();
 
-	JPContext* getContext()
-	{
-		return m_Context;
-	}
-
-	virtual JPPyObject getCallable(const string& cname) = 0;
+	virtual JPPyObject getCallable(const string& cname, int& addSelf) = 0;
 	static void releaseProxyPython(void* host);
 
-protected:
-	JPContext*    m_Context;
+	PyJPProxy* getInstance()
+	{
+		return m_Instance;
+	}
+
 	PyJPProxy*    m_Instance;
 	JPObjectRef   m_Proxy;
 	JPClassList   m_InterfaceClasses;
@@ -53,25 +51,25 @@ protected:
 class JPProxyDirect : public JPProxy
 {
 public:
-	JPProxyDirect(JPContext* context, PyJPProxy* inst, JPClassList& intf);
+	JPProxyDirect(PyJPProxy* inst, JPClassList& intf);
 	~JPProxyDirect() override;
-	JPPyObject getCallable(const string& cname) override;
+	JPPyObject getCallable(const string& cname, int& addSelf) override;
 } ;
 
 class JPProxyIndirect : public JPProxy
 {
 public:
-	JPProxyIndirect(JPContext* context, PyJPProxy* inst, JPClassList& intf);
+	JPProxyIndirect(PyJPProxy* inst, JPClassList& intf);
 	~JPProxyIndirect() override;
-	JPPyObject getCallable(const string& cname) override;
+	JPPyObject getCallable(const string& cname, int& addSelf) override;
 } ;
 
 class JPProxyFunctional : public JPProxy
 {
 public:
-	JPProxyFunctional(JPContext* context, PyJPProxy* inst, JPClassList& intf);
+	JPProxyFunctional(PyJPProxy* inst, JPClassList& intf);
 	~JPProxyFunctional() override;
-	JPPyObject getCallable(const string& cname) override;
+	JPPyObject getCallable(const string& cname, int& addSelf) override;
 private:
 	JPFunctional *m_Functional;
 } ;
@@ -98,4 +96,4 @@ private:
 	jfieldID   m_InstanceID;
 } ;
 
-#endif // JPPROXY_H
\ No newline at end of file
+#endif // JPPROXY_H
