@@ -31,8 +31,7 @@ JPArrayClass::JPArrayClass(JPJavaFrame& frame,
 }
 
 JPArrayClass::~JPArrayClass()
-{
-}
+= default;
 
 JPMatch::Type JPArrayClass::findJavaConversion(JPMatch &match)
 {
@@ -53,7 +52,7 @@ JPMatch::Type JPArrayClass::findJavaConversion(JPMatch &match)
 
 void JPArrayClass::getConversionInfo(JPConversionInfo &info)
 {
-	JPJavaFrame frame = JPJavaFrame::outer(m_Context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	objectConversion->getInfo(this, info);
 	charArrayConversion->getInfo(this, info);
 	byteArrayConversion->getInfo(this, info);
@@ -67,7 +66,7 @@ JPPyObject JPArrayClass::convertToPythonObject(JPJavaFrame& frame, jvalue value,
 	JP_TRACE_IN("JPArrayClass::convertToPythonObject");
 	if (!cast)
 	{
-		if (value.l == NULL)
+		if (value.l == nullptr)
 			return JPPyObject::getNone();
 	}
 	JPPyObject wrapper = PyJPClass_create(frame, this);
@@ -79,7 +78,7 @@ JPPyObject JPArrayClass::convertToPythonObject(JPJavaFrame& frame, jvalue value,
 jvalue JPArrayClass::convertToJavaVector(JPJavaFrame& frame, JPPyObjectVector& refs, jsize start, jsize end)
 {
 	JP_TRACE_IN("JPArrayClass::convertToJavaVector");
-	jsize length = (jsize) (end - start);
+	auto length = (jsize) (end - start);
 
 	jarray array = m_ComponentType->newArrayOf(frame, length);
 	jvalue res;
