@@ -32,12 +32,12 @@ m_PrimitiveType(primitiveType)
 		m_CtorID = frame.GetMethodID(clss, "<init>", s.c_str());
 	}
 
-	m_DoubleValueID = NULL;
-	m_FloatValueID = NULL;
-	m_LongValueID = NULL;
-	m_IntValueID = NULL;
-	m_BooleanValueID = NULL;
-	m_CharValueID = NULL;
+	m_DoubleValueID = nullptr;
+	m_FloatValueID = nullptr;
+	m_LongValueID = nullptr;
+	m_IntValueID = nullptr;
+	m_BooleanValueID = nullptr;
+	m_CharValueID = nullptr;
 
 	if (name != "java.lang.Void" && name != "java.lang.Boolean" && name != "java.lang.Character" )
 	{
@@ -60,8 +60,7 @@ m_PrimitiveType(primitiveType)
 }
 
 JPBoxedType::~JPBoxedType()
-{
-}
+= default;
 
 JPMatch::Type JPBoxedType::findJavaConversion(JPMatch &match)
 {
@@ -85,7 +84,7 @@ JPMatch::Type JPBoxedType::findJavaConversion(JPMatch &match)
 void JPBoxedType::getConversionInfo(JPConversionInfo &info)
 {
 	JP_TRACE_IN("JPBoxedType::getConversionInfo");
-	JPJavaFrame frame = JPJavaFrame::outer(m_Context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	m_PrimitiveType->getConversionInfo(info);
 	JPPyObject::call(PyObject_CallMethod(info.expl, "extend", "O", info.implicit));
 	JPPyObject::call(PyObject_CallMethod(info.implicit, "clear", ""));
@@ -106,7 +105,7 @@ JPPyObject JPBoxedType::convertToPythonObject(JPJavaFrame& frame, jvalue value,
 	if (!cast)
 	{
 		// This loses type
-		if (value.l == NULL)
+		if (value.l == nullptr)
 		{
 			return JPPyObject::getNone();
 		}
@@ -118,13 +117,13 @@ JPPyObject JPBoxedType::convertToPythonObject(JPJavaFrame& frame, jvalue value,
 
 	JPPyObject wrapper = PyJPClass_create(frame, cls);
 	JPPyObject obj;
-	JPContext *context = frame.getContext();
+	JPContext *context = JPContext_global;
 	if (this->getPrimitive() == context->_char)
 	{
 		jchar value2 = 0;
 		// Not null get the char value
-		if (value.l != 0)
-			value2 = context->_char->getValueFromObject(JPValue(this, value)).getValue().c;
+		if (value.l != nullptr)
+			value2 = context->_char->getValueFromObject(frame, JPValue(this, value)).getValue().c;
 		// Create a char string object
 		obj = JPPyObject::call(PyJPChar_Create((PyTypeObject*) wrapper.get(), value2));
 	} else
