@@ -16,9 +16,8 @@
 #include "jpype.h"
 #include "jp_monitor.h"
 
-JPMonitor::JPMonitor(JPContext* context, jobject value) : m_Value(context, value)
+JPMonitor::JPMonitor(jobject value) : m_Value(value)
 {
-	m_Context = context;
 }
 
 JPMonitor::~JPMonitor()
@@ -29,13 +28,13 @@ void JPMonitor::enter()
 	// This can hold off for a while so we need to release resource
 	// so that we don't dead lock.
 	JPPyCallRelease call;
-	JPJavaFrame frame = JPJavaFrame::outer(m_Context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	frame.MonitorEnter(m_Value.get());
 }
 
 void JPMonitor::exit()
 {
-	JPJavaFrame frame = JPJavaFrame::outer(m_Context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	frame.MonitorExit(m_Value.get());
 }
 
