@@ -28,8 +28,7 @@ JPObjectType::JPObjectType(JPJavaFrame& frame,
 }
 
 JPObjectType::~JPObjectType()
-{
-}
+= default;
 
 JPMatch::Type JPObjectType::findJavaConversion(JPMatch& match)
 {
@@ -53,7 +52,7 @@ JPMatch::Type JPObjectType::findJavaConversion(JPMatch& match)
 void JPObjectType::getConversionInfo(JPConversionInfo &info)
 {
 	JP_TRACE_IN("JPObjectType::getConversionInfo");
-	JPJavaFrame frame = JPJavaFrame::outer(m_Context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	nullConversion->getInfo(this, info);
 	objectConversion->getInfo(this, info);
 	stringConversion->getInfo(this, info);
@@ -65,4 +64,4 @@ void JPObjectType::getConversionInfo(JPConversionInfo &info)
 	hintsConversion->getInfo(this, info);
 	PyList_Append(info.ret, PyJPClass_create(frame, this).get());
 	JP_TRACE_OUT;
-}
\ No newline at end of file
+}
