@@ -150,7 +150,13 @@ void JPypeTracer::tracePythonObject(const char* msg, PyObject* ref)
 	if (ref != nullptr)
 	{
 		std::stringstream str;
-		str << msg << " " << (void*) ref << " " << ref->ob_refcnt << " " << Py_TYPE(ref)->tp_name;
+		str << msg << " " << (void*) ref << " "<<
+    #ifndef Py_GIL_DISABLED
+        Py_REFCNT(ref)
+    #else
+        -1
+    #endif
+        << " " << Py_TYPE(ref)->tp_name;
 		JPypeTracer::trace1("PY", str.str().c_str());
 
 	} else
@@ -204,4 +210,4 @@ void JPypeTracer::traceLocks(const string& msg, void* ref)
 	JPYPE_TRACING_OUTPUT.flush();
 }
 
-// GCOVR_EXCL_STOP
\ No newline at end of file
+// GCOVR_EXCL_STOP
