@@ -47,7 +47,7 @@ void JPTypeFactory_rethrow(JPJavaFrame& frame)
 		throw;
 	} catch (JPypeException& ex)
 	{
-		ex.toJava(frame.getContext());
+		ex.toJava();
 	} catch (...)  // GCOVR_EXCL_LINE
 	{
 		// GCOVR_EXCL_START
@@ -68,7 +68,6 @@ template <class T> void convert(JPJavaFrame& frame, jlongArray array, vector<T>&
 	{
 		out[i] = (T) values[i];
 	}
-	return;
 }
 
 #ifdef JP_TRACING_ENABLE
@@ -91,11 +90,10 @@ extern "C"
 JNIEXPORT void JNICALL Java_org_jpype_manager_TypeFactoryNative_newWrapper(
 		JNIEnv *env, jobject self, jlong contextPtr, jlong jcls)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_newWrapper");
 	JPPyCallAcquire callback;
-	JPClass* cls = (JPClass*) jcls;
+	auto* cls = (JPClass*) jcls;
 	PyJPClass_hook(frame, cls);
 	JP_JAVA_CATCH();  // GCOVR_EXCL_LINE
 }
@@ -105,8 +103,8 @@ JNIEXPORT void JNICALL Java_org_jpype_manager_TypeFactoryNative_destroy(
 		jlongArray resources,
 		jint sz)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
+	auto* context = frame.getContext();
 	JP_JAVA_TRY("JPTypeFactory_destroy");
 	JPPrimitiveArrayAccessor<jlongArray, jlong*> accessor(frame, resources,
 			&JPJavaFrame::GetLongArrayElements, &JPJavaFrame::ReleaseLongArrayElements);
@@ -126,15 +124,14 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_defineMethodDis
 		jlongArray overloadPtrs,
 		jint modifiers)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_defineMethodDispatch");
-	JPClass* cls = (JPClass*) clsPtr;
+	auto* cls = (JPClass*) clsPtr;
 	JPMethodList overloadList;
 	convert(frame, overloadPtrs, overloadList);
 	string cname = frame.toStringUTF8(name);
 	JP_TRACE(cname);
-	JPMethodDispatch* dispatch = new JPMethodDispatch(cls, cname, overloadList, modifiers);
+	auto* dispatch = new JPMethodDispatch(cls, cname, overloadList, modifiers);
 	return (jlong) dispatch;
 	JP_JAVA_CATCH(0);  // GCOVR_EXCL_LINE
 }
@@ -147,12 +144,11 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_defineArrayClas
 		jlong componentClass,
 		jint modifiers)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_defineArrayClass");
 	string cname = frame.toStringUTF8(name);
 	JP_TRACE(cname);
-	JPArrayClass* result = new JPArrayClass(frame, cls,
+	auto* result = new JPArrayClass(frame, cls,
 			cname,
 			(JPClass*) superClass,
 			(JPClass*) componentClass,
@@ -170,15 +166,15 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_defineObjectCla
 		jint modifiers)
 {
 	// All resources are created here are owned by Java and deleted by Java shutdown routine
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
+	auto* context = frame.getContext();
 	JP_JAVA_TRY("JPTypeFactory_defineObjectClass");
 	string className = frame.toStringUTF8(name);
 	JP_TRACE(className);
 	JPClassList interfaces;
-	if (interfacePtrs != NULL)
+	if (interfacePtrs != nullptr)
 		convert(frame, interfacePtrs, interfaces);
-	JPClass* result = NULL;
+	JPClass* result = nullptr;
 	if (!JPModifier::isSpecial(modifiers))
 	{
 		// Create a normal class
@@ -290,7 +286,7 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_defineObjectCla
 		return (jlong) (context->_java_lang_reflect_Field
 			= new JPClass(frame, cls, className, (JPClass*) superClass, interfaces, modifiers));
 
-	stringstream ss;
+	std::stringstream ss;
 	ss << "Special class not defined for " << className;
 	JP_RAISE(PyExc_RuntimeError, ss.str());
 	return (jlong) result;
@@ -305,8 +301,8 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_definePrimitive
 		jint modifiers)
 {
 	// These resources are created by the boxed types
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
+	auto* context = frame.getContext();
 	JP_JAVA_TRY("JPTypeFactory_definePrimitive");
 	string cname = frame.toStringUTF8(name);
 	JP_TRACE(cname);
@@ -367,10 +363,9 @@ JNIEXPORT void JNICALL Java_org_jpype_manager_TypeFactoryNative_assignMembers(
 		jlongArray methodPtrs,
 		jlongArray fieldPtrs)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_assignMembers");
-	JPClass* cls = (JPClass*) clsPtr;
+	auto* cls = (JPClass*) clsPtr;
 	JPMethodDispatchList methodList;
 	convert(frame, methodPtrs, methodList);
 
@@ -392,8 +387,7 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_defineField(
 		jlong fieldType,
 		jint modifiers)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_defineField");
 	string cname = frame.toStringUTF8(name);
 	JP_TRACE("class", cls);
@@ -415,8 +409,7 @@ JNIEXPORT jlong JNICALL Java_org_jpype_manager_TypeFactoryNative_defineMethod(
 		jobject method,
 		jlongArray overloadList, jint modifiers)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_defineMethod");
 	jmethodID mid = frame.FromReflectedMethod(method);
 	JPMethodList cover;
@@ -440,13 +433,12 @@ JNIEXPORT void JNICALL Java_org_jpype_manager_TypeFactoryNative_populateMethod(
 		jlongArray argumentTypes
 		)
 {
-	JPContext* context = (JPContext*) contextPtr;
-	JPJavaFrame frame = JPJavaFrame::external(context, env);
+	JPJavaFrame frame = JPJavaFrame::external(env);
 	JP_JAVA_TRY("JPTypeFactory_populateMethod");
 	JPClassList cargs;
 	convert(frame, argumentTypes, cargs);
-	JPMethod *methodPtr = (JPMethod*) method;
-	methodPtr->setParameters((JPClass*) returnType, cargs);
+	auto *methodPtr = (JPMethod*) method;
+	methodPtr->setParameters((JPClass*) returnType, std::move(cargs));
 	JP_JAVA_CATCH();  // GCOVR_EXCL_LINE
 }
 
