@@ -91,7 +91,7 @@ PyObject *PyJPChar_Create(PyTypeObject *type, Py_UCS2 p)
 	self->m_Data[3] = 0;
 
 	// Values taken from internal/cpython/unicode.h
-	
+
 	// Mark the type in unicode
 	_PyUnicode_LENGTH(self) = 1;
 	_PyUnicode_HASH(self) = -1;
@@ -120,7 +120,7 @@ PyObject *PyJPChar_Create(PyTypeObject *type, Py_UCS2 p)
 		char *data = (char*) ( ((PyCompactUnicodeObject*) self) + 1);
 		data[0] = (char) p;
 		data[1] = 0;
-	
+
 #if PY_VERSION_HEX < 0x030c0000
 		_PyUnicode_WSTR_LENGTH(self) = 0;
 		_PyUnicode_WSTR(self) = nullptr;
@@ -157,6 +157,7 @@ PyObject *PyJPChar_Create(PyTypeObject *type, Py_UCS2 p)
  */
 Py_UCS2 fromJPValue(const JPValue & value)
 {
+	JPJavaFrame frame = JPJavaFrame::outer();
 	JPClass* cls = value.getClass();
 	if (cls->isPrimitive())
 		return (Py_UCS2) (value.getValue().c);
@@ -164,7 +165,7 @@ Py_UCS2 fromJPValue(const JPValue & value)
 	if (value.getValue().l == nullptr)
 		return (Py_UCS2) - 1;
 	else
-		return (Py_UCS2) (pcls->getValueFromObject(value).getValue().c);
+		return (Py_UCS2) (pcls->getValueFromObject(frame, value).getValue().c);
 }
 
 /** Get the value of the char.  Does not touch Java.
@@ -196,10 +197,7 @@ static PyObject * PyJPChar_new(PyTypeObject *type, PyObject *pyargs, PyObject *
 		return nullptr;
 	}  // GCOVR_EXCL_STOP
 
-	JPContext *context = PyJPModule_getContext();
-
 	// Create an instance (this may fail)
-	JPJavaFrame frame = JPJavaFrame::outer(context);
 	if (PyTuple_Size(pyargs) != 1)
 	{
 		PyErr_SetString(PyExc_TypeError, "Java chars require one argument");
@@ -209,10 +207,12 @@ static PyObject * PyJPChar_new(PyTypeObject *type, PyObject *pyargs, PyObject *
 	JPValue jv;
 	PyObject *in = PyTuple_GetItem(pyargs, 0);
 	Py_UCS4 cv = ord(in);
+
+	JPJavaFrame frame = JPJavaFrame::outer();
 	if (cv != (Py_UCS4) - 1)
 	{
 		JPPyObject v = JPPyObject::call(PyLong_FromLong(cv));
-		JPPyObject args0 = JPPyObject::call(PyTuple_Pack(1, v.get()));
+		JPPyObject args0 = JPPyTuple_Pack(v.get());
 		JPPyObjectVector args(args0.get());
 		jv = cls->newInstance(frame, args);
 	} else if (PyIndex_Check(in))
@@ -222,7 +222,7 @@ static PyObject * PyJPChar_new(PyTypeObject *type, PyObject *pyargs, PyObject *
 	} else if (PyFloat_Check(in))
 	{
 		JPPyObject v = JPPyObject::call(PyNumber_Long(in));
-		JPPyObject args0 = JPPyObject::call(PyTuple_Pack(1, v.get()));
+		JPPyObject args0 = JPPyTuple_Pack(v.get());
 		JPPyObjectVector args(args0.get());
 		jv = cls->newInstance(frame, args);
 	} else
@@ -242,7 +242,6 @@ static PyObject * PyJPChar_new(PyTypeObject *type, PyObject *pyargs, PyObject *
 static PyObject *PyJPChar_str(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_str");
-	PyJPModule_getContext(); // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (javaSlot == nullptr)
 	{  // GCOVR_EXCL_START
@@ -259,7 +258,6 @@ static PyObject *PyJPChar_str(PyJPChar *self)
 static PyObject *PyJPChar_repr(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_repr");
-	PyJPModule_getContext(); // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (javaSlot == nullptr)
 	{  // GCOVR_EXCL_START
@@ -276,7 +274,6 @@ static PyObject *PyJPChar_repr(PyJPChar *self)
 static PyObject *PyJPChar_index(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_index");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return nullptr;
@@ -287,7 +284,6 @@ static PyObject *PyJPChar_index(PyJPChar *self)
 static PyObject *PyJPChar_float(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_float");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return nullptr;
@@ -298,7 +294,6 @@ static PyObject *PyJPChar_float(PyJPChar *self)
 static PyObject *PyJPChar_abs(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_nop");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return nullptr;
@@ -312,7 +307,6 @@ static PyObject *PyJPChar_abs(PyJPChar *self)
 static Py_ssize_t PyJPChar_len(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_nop");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return -1;
@@ -325,7 +319,7 @@ static PyObject *apply(PyObject *first, PyObject *second, PyObject* (*func)(PyOb
 	JPValue *slot0 = PyJPValue_getJavaSlot(first);
 	JPValue *slot1 = PyJPValue_getJavaSlot(second);
 	if (slot0 != nullptr && slot1 != nullptr)
-	{	
+	{
 		if (assertNotNull(slot0))
 			return nullptr;
 		if (assertNotNull(slot1))
@@ -357,7 +351,6 @@ static PyObject *apply(PyObject *first, PyObject *second, PyObject* (*func)(PyOb
 static  PyObject *PyJPChar_and(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_and");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_And);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -365,7 +358,6 @@ static  PyObject *PyJPChar_and(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_or(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_or");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Or);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -373,7 +365,6 @@ static  PyObject *PyJPChar_or(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_xor(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_xor");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Xor);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -381,11 +372,10 @@ static  PyObject *PyJPChar_xor(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_add(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_add");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *slot0 = PyJPValue_getJavaSlot(first);
 	JPValue *slot1 = PyJPValue_getJavaSlot(second);
 	if (slot1 != nullptr && slot0 != nullptr)
-	{	
+	{
 		if (assertNotNull(slot0))
 			return nullptr;
 		if (assertNotNull(slot1))
@@ -424,7 +414,6 @@ static  PyObject *PyJPChar_add(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_subtract(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_subtract");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Subtract);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -432,7 +421,6 @@ static  PyObject *PyJPChar_subtract(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_mult(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_mult");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Multiply);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -440,7 +428,6 @@ static  PyObject *PyJPChar_mult(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_rshift(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_rshift");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Rshift);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -448,7 +435,6 @@ static  PyObject *PyJPChar_rshift(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_lshift(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_lshift");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Lshift);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -456,7 +442,6 @@ static  PyObject *PyJPChar_lshift(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_floordiv(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_floordiv");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_FloorDivide);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -464,7 +449,6 @@ static  PyObject *PyJPChar_floordiv(PyObject *first, PyObject *second)
 static  PyObject *PyJPChar_divmod(PyObject *first, PyObject *second)
 {
 	JP_PY_TRY("PyJPChar_divmod");
-	PyJPModule_getContext();  // Check that JVM is running
 	return apply(first, second, PyNumber_Divmod);
 	JP_PY_CATCH(nullptr);  // GCOVR_EXCL_LINE
 }
@@ -472,7 +456,6 @@ static  PyObject *PyJPChar_divmod(PyObject *first, PyObject *second)
 static PyObject *PyJPChar_neg(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_neg");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return nullptr;
@@ -485,7 +468,6 @@ static PyObject *PyJPChar_neg(PyJPChar *self)
 static PyObject *PyJPChar_pos(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPChar_pos");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return nullptr;
@@ -498,7 +480,6 @@ static PyObject *PyJPChar_pos(PyJPChar *self)
 static PyObject *PyJPChar_inv(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPObject_neg");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (assertNotNull(javaSlot))
 		return nullptr;
@@ -511,7 +492,6 @@ static PyObject *PyJPChar_inv(PyJPChar *self)
 static PyObject *PyJPJChar_compare(PyObject *self, PyObject *other, int op)
 {
 	JP_PY_TRY("PyJPJChar_compare");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot1 = PyJPValue_getJavaSlot(other);
 	JPValue *javaSlot0 = PyJPValue_getJavaSlot(self);
 	if (isNull(javaSlot0))
@@ -576,7 +556,6 @@ static PyObject *PyJPJChar_compare(PyObject *self, PyObject *other, int op)
 static Py_hash_t PyJPChar_hash(PyObject *self)
 {
 	JP_PY_TRY("PyJPObject_hash");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot(self);
 	if (isNull(javaSlot))
 		return Py_TYPE(Py_None)->tp_hash(Py_None);
@@ -587,7 +566,6 @@ static Py_hash_t PyJPChar_hash(PyObject *self)
 static int PyJPChar_bool(PyJPChar *self)
 {
 	JP_PY_TRY("PyJPObject_bool");
-	PyJPModule_getContext();  // Check that JVM is running
 	JPValue *javaSlot = PyJPValue_getJavaSlot((PyObject*) self);
 	if (isNull(javaSlot))
 		return 0;
@@ -597,12 +575,10 @@ static int PyJPChar_bool(PyJPChar *self)
 
 
 static PyMethodDef charMethods[] = {
-	//	{"thing", (PyCFunction) PyJPMethod_matchReport, METH_VARARGS, ""},
 	{nullptr},
 };
 
 struct PyGetSetDef charGetSet[] = {
-	//	{"thing", (getter) PyJPMethod_getSelf, NULL, NULL, NULL},
 	{nullptr},
 };
 
@@ -655,9 +631,8 @@ static PyType_Spec charSpec = {
 void PyJPChar_initType(PyObject* module)
 {
 	// We will inherit from str and JObject
-	PyObject *bases = PyTuple_Pack(2, &PyUnicode_Type, PyJPObject_Type);
-	PyJPChar_Type = (PyTypeObject*) PyJPClass_FromSpecWithBases(&charSpec, bases);
-	Py_DECREF(bases);
+	JPPyObject bases = JPPyTuple_Pack(&PyUnicode_Type, PyJPObject_Type);
+	PyJPChar_Type = (PyTypeObject*) PyJPClass_FromSpecWithBases(&charSpec, bases.get());
 	JP_PY_CHECK(); // GCOVR_EXCL_LINE
 	PyModule_AddObject(module, "_JChar", (PyObject*) PyJPChar_Type);
 	JP_PY_CHECK(); // GCOVR_EXCL_LINE
