@@ -58,82 +58,18 @@ static int PyJPClass_clear(PyJPClass *self)
 	return 0;
 }
 
-PyObject *PyJPClass_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
-{
-	JP_PY_TRY("PyJPClass_new");
-	if (PyTuple_Size(args) != 3)
-		JP_RAISE(PyExc_TypeError, "Java class meta required 3 arguments");
-
-	JP_BLOCK("PyJPClass_new::verify")
-	{
-		// Watch for final classes
-		PyObject *bases = PyTuple_GetItem(args, 1);
-		Py_ssize_t len = PyTuple_Size(bases);
-		for (Py_ssize_t i = 0; i < len; ++i)
-		{
-			PyObject *item = PyTuple_GetItem(bases, i);
-			JPClass *cls = PyJPClass_getJPClass(item);
-			if (cls != nullptr && cls->isFinal())
-			{
-				PyErr_Format(PyExc_TypeError, "Cannot extend final class '%s'",
-						((PyTypeObject*) item)->tp_name);
-			}
-		}
-	}
-
-	int magic = 0;
-	if (kwargs == PyJPClassMagic || (kwargs != nullptr && PyDict_GetItemString(kwargs, "internal") != nullptr))
-	{
-		magic = 1;
-		kwargs = nullptr;
-	}
-	if (magic == 0)
-	{
-		PyErr_Format(PyExc_TypeError, "Java classes cannot be extended in Python");
-		return nullptr;
-	}
-
-	auto *typenew = (PyTypeObject*) PyType_Type.tp_new(type, args, kwargs);
-
-	// GCOVR_EXCL_START
-	// Sanity checks.  Not testable
-	if (typenew == nullptr)
-		return nullptr;
-	if (typenew->tp_finalize != nullptr && typenew->tp_finalize != (destructor) PyJPValue_finalize)
-	{
-		Py_DECREF(typenew);
-		PyErr_SetString(PyExc_TypeError, "finalizer conflict");
-		return nullptr;
-	}
-
-	// This sanity check is trigger if the user attempts to build their own
-	// type wrapper with a __del__ method defined.  It is hard to trigger.
-	if (typenew->tp_alloc != (allocfunc) PyJPValue_alloc
-			&& typenew->tp_alloc != PyBaseObject_Type.tp_alloc)
-	{
-		Py_DECREF(typenew);
-		PyErr_SetString(PyExc_TypeError, "alloc conflict");
-		return nullptr;
-	}
-	// GCOVR_EXCL_STOP
-
-	typenew->tp_alloc = (allocfunc) PyJPValue_alloc;
-	typenew->tp_finalize = (destructor) PyJPValue_finalize;
-
-	if (PyObject_IsSubclass((PyObject*) typenew, (PyObject*) PyJPException_Type))
-	{
-		typenew->tp_new = PyJPException_Type->tp_new;
-	}
-	((PyJPClass*) typenew)->m_Doc = nullptr;
-	return (PyObject*) typenew;
-	JP_PY_CATCH(nullptr);
-}
-
 PyObject* examine(PyObject *module, PyObject *other);
 
 PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 {
 	JP_PY_TRY("PyJPClass_FromSpecWithBases");
+#if PY_VERSION_HEX>=0x030c0000
+	// Starting in Python 3.12 there is a function for creating from a meta class
+	// that replaces this madeness.
+	PyTypeObject *type = (PyTypeObject*) PyType_FromMetaclass((PyTypeObject*) PyJPClass_Type, NULL, spec, bases);
+	if (type == nullptr)
+		return (PyObject*) type;
+#else
 	// Python lacks a FromSpecWithMeta so we are going to have to fake it here.
 	auto* type = (PyTypeObject*) PyJPClass_Type->tp_alloc(PyJPClass_Type, 0);
 	auto* heap = (PyHeapTypeObject*) type;
@@ -148,7 +84,10 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 	heap->ht_name = heap->ht_qualname;
 	Py_INCREF(heap->ht_name);
 	if (bases == nullptr)
+	{
+		// do NOT use JPPyTuple_Pack here
 		type->tp_bases = PyTuple_Pack(1, (PyObject*) & PyBaseObject_Type);
+	}
 	else
 	{
 		type->tp_bases = bases;
@@ -174,6 +113,12 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 	{
 		switch (slot->slot)
 		{
+			case Py_tp_finalize:
+				type->tp_finalize = (destructor) slot->pfunc;
+				break;
+			case Py_tp_alloc:
+				type->tp_alloc = (allocfunc) slot->pfunc;
+				break;
 			case Py_tp_free:
 				type->tp_free = (freefunc) slot->pfunc;
 				break;
@@ -293,7 +238,7 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 	}
 
 	// GC objects are required to implement clear and traverse, this is a
-	// safety check to make sure we implemented all properly.   This error should
+	// safety check to make sure we implemented all properly.	This error should
 	// never happen in production code.
 	if (PyType_IS_GC(type) && (
 			type->tp_traverse==nullptr ||
@@ -302,6 +247,13 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 		PyErr_Format(PyExc_TypeError, "GC requirements failed for %s", spec->name);
 		JP_RAISE_PYTHON();
 	}
+
+#endif
+
+	// Make sure our memory model is used
+	type->tp_alloc = (allocfunc) PyJPValue_alloc;
+	type->tp_finalize = (destructor) PyJPValue_finalize;
+
 	PyType_Ready(type);
 	PyDict_SetItemString(type->tp_dict, "__module__", PyUnicode_FromString("_jpype"));
 	return (PyObject*) type;
@@ -311,8 +263,34 @@ PyObject* PyJPClass_FromSpecWithBases(PyType_Spec *spec, PyObject *bases)
 int PyJPClass_init(PyObject *self, PyObject *args, PyObject *kwargs)
 {
 	JP_PY_TRY("PyJPClass_init");
-	if (PyTuple_Size(args) == 1)
-		return 0;
+
+	if (!PyObject_IsInstance(self, (PyObject*) PyJPClass_Type))
+	{
+		PyErr_SetString(PyExc_TypeError, "Type incorrect");
+		return -1;
+	}
+
+	PyTypeObject *type = (PyTypeObject*) self;
+
+#if PY_VERSION_HEX >= 0x030d0000
+	// Python 3.13 - This flag will try to place the dictionary are part of the object which 
+	// adds an unknown number of bytes to the end of the object making it impossible
+	// to attach our needed data.  If we kill the flag then we get usable behavior.
+	type->tp_flags &= ~Py_TPFLAGS_INLINE_VALUES;
+#endif
+
+	// Verify that we were called internally
+	int magic = 0;
+	if (kwargs == PyJPClassMagic || (kwargs != nullptr && PyDict_GetItemString(kwargs, "internal") != nullptr))
+	{
+		magic = 1;
+		kwargs = nullptr;
+	}
+	if (magic == 0)
+	{
+		PyErr_Format(PyExc_TypeError, "Java classes cannot be extended in Python");
+		return -1;
+	}
 
 	// Set the host object
 	PyObject *name = nullptr;
@@ -327,20 +305,61 @@ int PyJPClass_init(PyObject *self, PyObject *args, PyObject *kwargs)
 		PyErr_SetString(PyExc_TypeError, "Bases must be a tuple");
 		return -1;
 	}
-	for (int i = 0; i < PyTuple_Size(bases); ++i)
+
+	JP_BLOCK("PyJPClass_new::verify")
 	{
-		if (!PyJPClass_Check(PyTuple_GetItem(bases, i)))
+		// Watch for final classes
+		Py_ssize_t len = PyTuple_Size(bases);
+		for (Py_ssize_t i = 0; i < len; ++i)
 		{
-			PyErr_SetString(PyExc_TypeError, "All bases must be Java types");
-			return -1;
+			PyObject *item = PyTuple_GetItem(bases, i);
+			JPClass *cls = PyJPClass_getJPClass(item);
+			if (cls != nullptr && cls->isFinal())
+			{
+				PyErr_Format(PyExc_TypeError, "Cannot extend final class '%s'",
+						((PyTypeObject*) item)->tp_name);
+			}
 		}
 	}
 
+	// We must make sure that all classes have our allocator
+	type->tp_alloc = (allocfunc) PyJPValue_alloc;
+	type->tp_finalize = (destructor) PyJPValue_finalize;
+	((PyJPClass*) self)->m_Doc = nullptr;
+
 	// Call the type init
 	int rc = PyType_Type.tp_init(self, args, nullptr);
 	if (rc == -1)
 		return rc; // GCOVR_EXCL_LINE no clue how to trigger this one
 
+	// GCOVR_EXCL_START
+	// Sanity checks.  Not testable
+	if (type == nullptr)
+		return -1;
+	if (type->tp_finalize != nullptr && type->tp_finalize != (destructor) PyJPValue_finalize)
+	{
+		PyErr_SetString(PyExc_TypeError, "finalizer conflict");
+		return -1;
+	}
+
+	// This sanity check is trigger if the user attempts to build their own
+	// type wrapper with a __del__ method defined.	It is hard to trigger.
+	if (type->tp_alloc != (allocfunc) PyJPValue_alloc
+			&& type->tp_alloc != PyBaseObject_Type.tp_alloc)
+	{
+		PyErr_SetString(PyExc_TypeError, "alloc conflict");
+		return -1;
+	}
+	// GCOVR_EXCL_STOP
+
+#if PY_VERSION_HEX < 0x03090000
+	// This was required at one point but I don't know what version it applied to.
+	if (PyObject_IsSubclass((PyObject*) type, (PyObject*) PyJPException_Type))
+	{
+		type->tp_new = PyJPException_Type->tp_new;
+	}
+#endif
+
 	return rc;
 	JP_PY_CATCH(-1);
 }
@@ -504,8 +523,7 @@ PyObject* PyJPClass_subclasscheck(PyTypeObject *type, PyTypeObject *test)
 	}
 	// GCOVR_EXCL_STOP
 
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 
 	// Check for class inheritance first
 	JPClass *testClass = PyJPClass_getJPClass((PyObject*) test);
@@ -546,8 +564,7 @@ PyObject* PyJPClass_subclasscheck(PyTypeObject *type, PyTypeObject *test)
 static PyObject *PyJPClass_class(PyObject *self, PyObject *closure)
 {
 	JP_PY_TRY("PyJPClass_class");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	JPValue* javaSlot = PyJPValue_getJavaSlot(self);
 	if (javaSlot == nullptr)
 	{
@@ -561,8 +578,8 @@ static PyObject *PyJPClass_class(PyObject *self, PyObject *closure)
 static int PyJPClass_setClass(PyObject *self, PyObject *type, PyObject *closure)
 {
 	JP_PY_TRY("PyJPClass_setClass", self);
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
+	JPContext *context = frame.getContext();
 	JPValue* javaSlot = PyJPValue_getJavaSlot(type);
 	if (javaSlot == nullptr || javaSlot->getClass() != context->_java_lang_Class)
 	{
@@ -642,15 +659,13 @@ PyObject* PyJPClass_instancecheck(PyTypeObject *self, PyObject *test)
 	// JInterface is a meta
 	if ((PyObject*) self == _JInterface)
 	{
-		JPContext *context = PyJPModule_getContext();
-		JPJavaFrame frame = JPJavaFrame::outer(context);
+		JPJavaFrame frame = JPJavaFrame::outer();
 		JPClass *testClass = PyJPClass_getJPClass((PyObject*) test);
 		return PyBool_FromLong(testClass != nullptr && testClass->isInterface());
 	}
 	if ((PyObject*) self == _JException)
 	{
-		JPContext *context = PyJPModule_getContext();
-		JPJavaFrame frame = JPJavaFrame::outer(context);
+		JPJavaFrame frame = JPJavaFrame::outer();
 		JPClass *testClass = PyJPClass_getJPClass((PyObject*) test);
 		if (testClass)
 			return PyBool_FromLong(testClass->isThrowable());
@@ -661,8 +676,7 @@ PyObject* PyJPClass_instancecheck(PyTypeObject *self, PyObject *test)
 static PyObject *PyJPClass_canCast(PyJPClass *self, PyObject *other)
 {
 	JP_PY_TRY("PyJPClass_canCast");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 
 	JPClass *cls = self->m_Class;
 
@@ -679,8 +693,7 @@ static PyObject *PyJPClass_canCast(PyJPClass *self, PyObject *other)
 static PyObject *PyJPClass_canConvertToJava(PyJPClass *self, PyObject *other)
 {
 	JP_PY_TRY("PyJPClass_canConvertToJava");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 
 	JPClass *cls = self->m_Class;
 
@@ -723,13 +736,20 @@ static bool PySlice_CheckFull(PyObject *item)
 static PyObject *PyJPClass_array(PyJPClass *self, PyObject *item)
 {
 	JP_PY_TRY("PyJPClass_array");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
+	JPContext *context = frame.getContext();
 
 	if (self->m_Class == NULL)
 	{
-		PyErr_Format(PyExc_TypeError, "Cannot instantiate unspecified array type");
-		return NULL;
+		// This is only reachable through an internal Jpype type that doesn't have a
+		// Java class equivalent such as JArray.
+		// __getitem__ takes precedence over __class_getitem__ which forces us through
+		// this path.
+		// If __class_getitem__ is not implemented in this class, the raised AttributeError
+		// will make its way back to Python.
+		PyObject *res = PyObject_CallMethod((PyObject *)self, "__class_getitem__", "O", item);
+		Py_DECREF(item);
+		return res;
 	}
 
 	if (PyIndex_Check(item))
@@ -811,8 +831,7 @@ static PyObject *PyJPClass_array(PyJPClass *self, PyObject *item)
 static PyObject *PyJPClass_cast(PyJPClass *self, PyObject *other)
 {
 	JP_PY_TRY("PyJPClass_cast");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	JPClass *type = self->m_Class;
 	JPValue *val = PyJPValue_getJavaSlot(other);
 
@@ -867,7 +886,6 @@ static PyObject *PyJPClass_cast(PyJPClass *self, PyObject *other)
 		auto *array = (PyJPArray*) other;
 		if (array->m_Array->isSlice())
 		{
-			JPJavaFrame frame = JPJavaFrame::outer(context);
 			jvalue v;
 			v.l = array->m_Array->clone(frame, other);
 			return type->convertToPythonObject(frame, v, true).keep();
@@ -891,8 +909,7 @@ static PyObject *PyJPClass_castEq(PyJPClass *self, PyObject *other)
 static PyObject *PyJPClass_convertToJava(PyJPClass *self, PyObject *other)
 {
 	JP_PY_TRY("PyJPClass_convertToJava");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 
 	JPClass *cls = self->m_Class;
 
@@ -924,8 +941,7 @@ static PyObject *PyJPClass_repr(PyJPClass *self)
 static PyObject *PyJPClass_getDoc(PyJPClass *self, void *ctxt)
 {
 	JP_PY_TRY("PyJPMethod_getDoc");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	if (self->m_Doc)
 	{
 		Py_INCREF(self->m_Doc);
@@ -935,7 +951,7 @@ static PyObject *PyJPClass_getDoc(PyJPClass *self, void *ctxt)
 	// Pack the arguments
 	{
 		JP_TRACE("Pack arguments");
-		JPPyObject args = JPPyObject::call(PyTuple_Pack(1, self));
+		JPPyObject args = JPPyTuple_Pack(self);
 		JP_TRACE("Call Python");
 		self->m_Doc = PyObject_Call(_JClassDoc, args.get(), nullptr);
 		Py_XINCREF(self->m_Doc);
@@ -990,7 +1006,6 @@ static PyGetSetDef classGetSets[] = {
 static PyType_Slot classSlots[] = {
 	{ Py_tp_alloc, (void*) PyJPValue_alloc},
 	{ Py_tp_finalize, (void*) PyJPValue_finalize},
-	{ Py_tp_new, (void*) PyJPClass_new},
 	{ Py_tp_init, (void*) PyJPClass_init},
 	{ Py_tp_dealloc, (void*) PyJPClass_dealloc},
 	{ Py_tp_traverse, (void*) PyJPClass_traverse},
@@ -1021,9 +1036,8 @@ static PyType_Spec classSpec = {
 
 void PyJPClass_initType(PyObject* module)
 {
-	PyObject *bases = PyTuple_Pack(1, &PyType_Type);
-	PyJPClass_Type = (PyTypeObject*) PyType_FromSpecWithBases(&classSpec, bases);
-	Py_DECREF(bases);
+	JPPyObject bases = JPPyTuple_Pack(&PyType_Type);
+	PyJPClass_Type = (PyTypeObject*) PyType_FromSpecWithBases(&classSpec, bases.get());
 	JP_PY_CHECK();
 	PyModule_AddObject(module, "_JClass", (PyObject*) PyJPClass_Type);
 	JP_PY_CHECK();
@@ -1041,9 +1055,9 @@ JPClass* PyJPClass_getJPClass(PyObject* obj)
 		if (javaSlot == nullptr)
 			return nullptr;
 		JPClass *cls = javaSlot->getClass();
-		if (cls != cls->getContext()->_java_lang_Class)
+		JPJavaFrame frame = JPJavaFrame::outer();
+		if (cls != frame.getContext()->_java_lang_Class)
 			return nullptr;
-		JPJavaFrame frame = JPJavaFrame::outer(cls->getContext());
 		return frame.findClass((jclass) javaSlot->getJavaObject());
 	} catch (...) // GCOVR_EXCL_LINE
 	{
@@ -1059,7 +1073,7 @@ JPPyObject PyJPClass_getBases(JPJavaFrame &frame, JPClass* cls)
 
 	// Decide the base for this object
 	JPPyObject baseType;
-	JPContext *context = PyJPModule_getContext();
+	JPContext *context = frame.getContext();
 	JPClass *super = cls->getSuperClass();
 	if (dynamic_cast<JPBoxedType*> (cls) == cls)
 	{
@@ -1130,7 +1144,7 @@ JPPyObject PyJPClass_getBases(JPJavaFrame &frame, JPClass* cls)
  * Internal method for wrapping a returned Java class instance.
  *
  * This checks the cache for existing wrappers and then
- * transfers control to JClassFactory.  This is required because all of
+ * transfers control to JClassFactory.	This is required because all of
  * the post load stuff needs to be in Python.
  *
  * @param cls
@@ -1160,10 +1174,10 @@ void PyJPClass_hook(JPJavaFrame &frame, JPClass* cls)
 
 
 	JPPyObject members = JPPyObject::call(PyDict_New());
-	JPPyObject args = JPPyObject::call(PyTuple_Pack(3,
+	JPPyObject args = JPPyTuple_Pack(
 			JPPyString::fromStringUTF8(cls->getCanonicalName()).get(),
 			PyJPClass_getBases(frame, cls).get(),
-			members.get()));
+			members.get());
 
 	// Catch creation loop,  the process of creating our parent
 	host = (PyObject*) cls->getHost();
@@ -1201,7 +1215,7 @@ void PyJPClass_hook(JPJavaFrame &frame, JPClass* cls)
 
 	JP_TRACE("type new");
 	// Create the type using the meta class magic
-	JPPyObject vself = JPPyObject::call(PyJPClass_Type->tp_new(PyJPClass_Type, rc.get(), PyJPClassMagic));
+	JPPyObject vself = JPPyObject::call(PyJPClass_Type->tp_call((PyObject*) PyJPClass_Type, rc.get(), PyJPClassMagic));
 	auto *self = (PyJPClass*) vself.get();
 
 	// Attach the javaSlot
@@ -1216,6 +1230,6 @@ void PyJPClass_hook(JPJavaFrame &frame, JPClass* cls)
 
 	// Call the post load routine to attach inner classes
 	JP_TRACE("call post");
-	args = JPPyObject::call(PyTuple_Pack(1, self));
+	args = JPPyTuple_Pack(self);
 	JPPyObject rc2 = JPPyObject::call(PyObject_Call(_JClassPost, args.get(), nullptr));
 }
