@@ -30,35 +30,33 @@ struct PyJPField
 
 static void PyJPField_dealloc(PyJPField *self)
 {
-	self->m_Field = NULL;
+	self->m_Field = nullptr;
 	Py_TYPE(self)->tp_free(self);
 }
 
 static PyObject *PyJPField_get(PyJPField *self, PyObject *obj, PyObject *type)
 {
 	JP_PY_TRY("PyJPField_get");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	// Clear any pending interrupts if we are on the main thread.
 	if (hasInterrupt())
 		frame.clearInterrupt(false);
 	if (self->m_Field->isStatic())
 		return self->m_Field->getStaticField().keep();
-	if (obj == NULL)
+	if (obj == nullptr)
 		JP_RAISE(PyExc_AttributeError, "Field is not static");
 	JPValue *jval = PyJPValue_getJavaSlot(obj);
-	if (jval == NULL)
+	if (jval == nullptr)
 		JP_RAISE(PyExc_AttributeError, "Field requires instance value");
 
 	return self->m_Field->getField(jval->getValue().l).keep();
-	JP_PY_CATCH(NULL);
+	JP_PY_CATCH(nullptr);
 }
 
 static int PyJPField_set(PyJPField *self, PyObject *obj, PyObject *pyvalue)
 {
 	JP_PY_TRY("PyJPField_set");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	if (self->m_Field->isFinal())
 	{
 		PyErr_SetString(PyExc_AttributeError, "Field is final");
@@ -75,7 +73,7 @@ static int PyJPField_set(PyJPField *self, PyObject *obj, PyObject *pyvalue)
 		return -1;
 	}
 	JPValue *jval = PyJPValue_getJavaSlot(obj);
-	if (jval == NULL)
+	if (jval == nullptr)
 	{
 		PyErr_Format(PyExc_AttributeError, "Field requires instance value, not '%s'", Py_TYPE(obj)->tp_name);
 		return -1;
@@ -88,17 +86,16 @@ static int PyJPField_set(PyJPField *self, PyObject *obj, PyObject *pyvalue)
 static PyObject *PyJPField_repr(PyJPField *self)
 {
 	JP_PY_TRY("PyJPField_repr");
-	JPContext *context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	return PyUnicode_FromFormat("<java field '%s' of '%s'>",
 			self->m_Field->getName().c_str(),
 			self->m_Field->getClass()->getCanonicalName().c_str()
 			);
-	JP_PY_CATCH(NULL);
+	JP_PY_CATCH(nullptr);
 }
 
 static PyGetSetDef fieldGetSets[] = {
-	{0}
+	{nullptr}
 };
 
 static PyType_Slot fieldSlots[] = {
@@ -110,7 +107,7 @@ static PyType_Slot fieldSlots[] = {
 	{0}
 };
 
-PyTypeObject *PyJPField_Type = NULL;
+PyTypeObject *PyJPField_Type = nullptr;
 PyType_Spec PyJPFieldSpec = {
 	"_jpype._JField",
 	sizeof (PyJPField),
@@ -134,7 +131,7 @@ void PyJPField_initType(PyObject* module)
 JPPyObject PyJPField_create(JPField* m)
 {
 	JP_TRACE_IN("PyJPField_create");
-	PyJPField* self = (PyJPField*) PyJPField_Type->tp_alloc(PyJPField_Type, 0);
+	auto* self = (PyJPField*) PyJPField_Type->tp_alloc(PyJPField_Type, 0);
 	JP_PY_CHECK();
 	self->m_Field = m;
 	return JPPyObject::claim((PyObject*) self);
