@@ -58,13 +58,14 @@ static PyObject *PyJPPackage_new(PyTypeObject *type, PyObject *args, PyObject *k
 
 static void dtor(PyObject *self)
 {
+	// No need for exception if JVM is not running.
 	JPContext *context = JPContext_global;
 	if (context == nullptr || !context->isRunning())
 		return;
 	auto jo = (jobject) PyCapsule_GetPointer(self, nullptr);
 	if (jo == nullptr)
 		return;
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	frame.DeleteGlobalRef(jo);
 }
 
@@ -135,6 +136,7 @@ static PyObject *PyJPPackage_getattro(PyObject *self, PyObject *attr)
 	if (attrName.compare(0, 2, "__") == 0)
 		return PyObject_GenericGetAttr((PyObject*) self, attr);
 
+	// Check for JVM running first
 	JPContext* context = JPContext_global;
 	if (!context->isRunning())
 	{
@@ -143,7 +145,7 @@ static PyObject *PyJPPackage_getattro(PyObject *self, PyObject *attr)
 				PyModule_GetName(self), attr);
 		return nullptr;
 	}
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	jobject pkg = getPackage(frame, self);
 	if (pkg == nullptr)
 		return nullptr;
@@ -163,7 +165,7 @@ static PyObject *PyJPPackage_getattro(PyObject *self, PyObject *attr)
 			JPPyErrFrame err;
 			err.normalize();
 			err.clear();
-			JPPyObject tuple0 = JPPyObject::call(PyTuple_Pack(3, self, attr, err.m_ExceptionValue.get()));
+			JPPyObject tuple0 = JPPyTuple_Pack(self, attr, err.m_ExceptionValue.get());
 			PyObject *rc = PyObject_Call(h.get(), tuple0.get(), nullptr);
 			if (rc == nullptr)
 				return nullptr;
@@ -182,7 +184,7 @@ static PyObject *PyJPPackage_getattro(PyObject *self, PyObject *attr)
 	{
 		JPPyObject u = JPPyObject::call(PyUnicode_FromFormat("%s.%U",
 				PyModule_GetName(self), attr));
-		JPPyObject args = JPPyObject::call(PyTuple_Pack(1, u.get()));
+		JPPyObject args = JPPyTuple_Pack(u.get());
 		out = JPPyObject::call(PyObject_Call((PyObject*) PyJPPackage_Type, args.get(), nullptr));
 	} else
 	{
@@ -248,8 +250,7 @@ static PyObject *PyJPPackage_path(PyObject *self)
 static PyObject *PyJPPackage_dir(PyObject *self)
 {
 	JP_PY_TRY("PyJPPackage_dir");
-	JPContext* context = PyJPModule_getContext();
-	JPJavaFrame frame = JPJavaFrame::outer(context);
+	JPJavaFrame frame = JPJavaFrame::outer();
 	jobject pkg = getPackage(frame, self);
 	if (pkg == nullptr)
 		return nullptr;
@@ -284,7 +285,7 @@ static PyObject *PyJPPackage_cast(PyObject *self, PyObject *other)
 	PyObject* matmul = PyDict_GetItemString(dict, "__matmul__");
 	if (matmul == nullptr)
 		Py_RETURN_NOTIMPLEMENTED;
-	JPPyObject args = JPPyObject::call(PyTuple_Pack(2, self, other));
+	JPPyObject args = JPPyTuple_Pack(self, other);
 	return PyObject_Call(matmul, args.get(), nullptr);
 	JP_PY_CATCH(nullptr);
 }
@@ -338,7 +339,7 @@ static PyType_Spec packageSpec = {
 void PyJPPackage_initType(PyObject* module)
 {
 	// Inherit from module.
-	JPPyObject bases = JPPyObject::call(PyTuple_Pack(1, &PyModule_Type));
+	JPPyObject bases = JPPyTuple_Pack(&PyModule_Type);
 	packageSpec.basicsize = PyModule_Type.tp_basicsize;
 	PyJPPackage_Type = (PyTypeObject*) PyType_FromSpecWithBases(&packageSpec, bases.get());
 	JP_PY_CHECK();
