@@ -15,11 +15,12 @@
 #   See NOTICE file for details.
 #
 # *****************************************************************************
-import sys
-import jpype
-import common
 import random
+from unittest.util import safe_repr
+
 import _jpype
+
+import common
 import jpype
 from jpype import java
 from jpype.types import *
@@ -49,8 +50,8 @@ class JFloatTestCase(common.JPypeTestCase):
             b = -b
         if b < a * 1e-7:
             return
-        msg = self._formatMessage(msg, '%s == %s' % (safe_repr(first),
-                                                     safe_repr(second)))
+        msg = self._formatMessage(msg, '%s == %s' % (safe_repr(x),
+                                                     safe_repr(y)))
         raise self.failureException(msg)
 
     @common.requireInstrumentation
@@ -382,10 +383,10 @@ class JFloatTestCase(common.JPypeTestCase):
         self.assertElementsAlmostEqual(a, jarr)
 
     @common.requireNumpy
-    def testArrayInitFromNPFloat(self):
-        a = np.random.random(100).astype(np.float_)
+    def testArrayInitFromNPFloat16(self):
+        a = np.random.random(1000).astype(np.float16)
         jarr = JArray(JFloat)(a)
-        self.assertElementsAlmostEqual(a, jarr)
+        self.assertElementsEqual(a, jarr)
 
     @common.requireNumpy
     def testArrayInitFromNPFloat32(self):
@@ -441,3 +442,15 @@ class JFloatTestCase(common.JPypeTestCase):
             ja[:] = [1, 2, 3]
         with self.assertRaisesRegex(ValueError, "mismatch"):
             ja[:] = a
+
+    @common.requireNumpy
+    def testNPFloat16(self):
+        v= [0.000000e+00, 5.960464e-08, 1.788139e-07, 1.788139e-07, 4.172325e-07, 8.940697e-07, 1.847744e-06, 3.755093e-06, 7.569790e-06, 1.519918e-05, 3.045797e-05, 6.097555e-05, 6.103516e-05, 3.332520e-01, 1.000000e+00, 6.550400e+04, np.inf, -np.inf]
+        a = np.array(v, dtype=np.float16)
+        jarr = JArray(JFloat)(a)
+        for v1,v2 in zip(a, jarr):
+            self.assertEqual(v1,v2)
+        a = np.array([np.nan], dtype=np.float16)
+        jarr = JArray(JFloat)(a)
+        self.assertTrue(np.isnan(jarr[0]))
+
