@@ -19,6 +19,7 @@ import contextlib
 import sys
 
 from jpype import *
+import _jpype
 import common
 import subrun
 
@@ -135,6 +136,34 @@ class ProxyTestCase(common.JPypeTestCase):
             def testMethod1(self):
                 pass
 
+    def testDefault1(self):
+        itf1 = self.package.TestInterface1
+
+        @JImplements(itf1)
+        class MyImpl(object):
+            @JOverride
+            def testMethod1(self):
+                pass
+
+        obj = itf1@MyImpl()
+        self.assertEqual(obj.testDefault(), 1234)
+
+    def testDefault2(self):
+        itf1 = self.package.TestInterface1
+
+        @JImplements(itf1)
+        class MyImpl(object):
+            @JOverride
+            def testMethod1(self):
+                pass
+
+            @JOverride
+            def testDefault(self):
+                return 5678
+
+        obj = itf1@MyImpl()
+        self.assertEqual(obj.testDefault(), 5678)
+
     def testProxyImplementsForm2(self):
         itf1 = self.package.TestInterface1
         itf2 = self.package.TestInterface2
@@ -323,9 +352,17 @@ class ProxyTestCase(common.JPypeTestCase):
         t = ProxyTriggers()
         self.assertTrue(t.testEquals(b))
 
-    def testProxyFail(self):
-        with self.assertRaises(TypeError):
-            JProxy(inst=object(), dict={}, intf="java.io.Serializable")
+    def testProxyBoth(self):
+        myobj = object()
+        def myimpl(x):
+            self.assertEqual(myobj, x)
+            return 33
+        d = {
+            'testMethod1': myimpl,
+        }
+        itf1 = self.package.TestInterface1
+        jobj = itf1@JProxy(inst=myobj, dict=d, intf=itf1)
+        self.assertEqual(jobj.testMethod1(), 33)
 
     def testValid(self):
         @JImplements("java.util.Comparator")
@@ -508,6 +545,14 @@ class ProxyTestCase(common.JPypeTestCase):
                 def run(self):
                     pass
 
+    def testInternal(self):
+        with self.assertRaises(TypeError):
+            _jpype._JProxy(None, None, None)
+        with self.assertRaises(TypeError):
+            _jpype._JProxy(None, None, [])
+        with self.assertRaises(TypeError):
+            _jpype._JProxy(None, None, [type])
+
 
 @subrun.TestCase(individual=True)
 class TestProxyDefinitionWithoutJVM(common.JPypeTestCase):
@@ -560,3 +605,4 @@ class TestProxyDefinitionWithoutJVM(common.JPypeTestCase):
 
         startJVM()
         assert isinstance(MyImpl(), MyImpl)
+    
